The function pssm fits the model and outputs a pssm-object S4 object, this can input to pssm.survivalcurv which
outputs a function of time, that can be used to create time to
progression and survival curves for the model with specified covariate values.
In addition pssm.simulate is given to generate data to test the model.
Functions "llikef","rprog","sprog" are helper functions, methods "plot","print" and "summary" are available.